import PySimpleGUI as sg
from abstract_utilities.global_utils import global_registry, change_glob, update_registry, get_global_from_registry
from abstract_gui.simple_gui import global_bridge
from abstract_gui.simple_gui import window_manager
from abstract_gui.simple_gui.gui_template import get_gui_fun
